/*******************************************************************************
* File Name: toLogic.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "toLogic.h"


/*******************************************************************************
* Function Name: toLogic_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void toLogic_Write(uint8 value) 
{
    uint8 staticBits = (toLogic_DR & (uint8)(~toLogic_MASK));
    toLogic_DR = staticBits | ((uint8)(value << toLogic_SHIFT) & toLogic_MASK);
}


/*******************************************************************************
* Function Name: toLogic_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  toLogic_DM_STRONG     Strong Drive 
*  toLogic_DM_OD_HI      Open Drain, Drives High 
*  toLogic_DM_OD_LO      Open Drain, Drives Low 
*  toLogic_DM_RES_UP     Resistive Pull Up 
*  toLogic_DM_RES_DWN    Resistive Pull Down 
*  toLogic_DM_RES_UPDWN  Resistive Pull Up/Down 
*  toLogic_DM_DIG_HIZ    High Impedance Digital 
*  toLogic_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void toLogic_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(toLogic_0, mode);
}


/*******************************************************************************
* Function Name: toLogic_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro toLogic_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 toLogic_Read(void) 
{
    return (toLogic_PS & toLogic_MASK) >> toLogic_SHIFT;
}


/*******************************************************************************
* Function Name: toLogic_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 toLogic_ReadDataReg(void) 
{
    return (toLogic_DR & toLogic_MASK) >> toLogic_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(toLogic_INTSTAT) 

    /*******************************************************************************
    * Function Name: toLogic_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 toLogic_ClearInterrupt(void) 
    {
        return (toLogic_INTSTAT & toLogic_MASK) >> toLogic_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
